>From b942ae05cb057bb582007ac1a274787516a88cbe Mon Sep 17 00:00:00 2001
From: Erwan Tulou <brezhoneg1@yahoo.fr>
Date: Mon, 25 May 2009 13:39:23 +0200
Subject: [PATCH] snapshot vout plugin : avoid variables conflicting with vlc core

---
 modules/video_output/snapshot.c |   62 +++++++++++++++++++-------------------
 1 files changed, 31 insertions(+), 31 deletions(-)

diff --git a/modules/video_output/snapshot.c b/modules/video_output/snapshot.c
index 5b6c4c3..8b314e0 100644
--- a/modules/video_output/snapshot.c
+++ b/modules/video_output/snapshot.c
@@ -26,10 +26,10 @@
  * keep a cache of low-res snapshots.
  * The snapshot structure is defined in include/snapshot.h
  * In order to access the current snapshot cache, object variables are used:
- *   snapshot-list-pointer : the pointer on the first element in the list
- *   snapshot-datasize     : size of a snapshot
+ *   snapmod-list-pointer : the pointer on the first element in the list
+ *   snapmod-datasize     : size of a snapshot
  *                           (also available in snapshot_t->i_datasize)
- *   snapshot-cache-size   : size of the cache list
+ *   snapmod-cache-size   : size of the cache list
  *
  * It is used for the moment by the CORBA module and a specialized
  * python-vlc binding.
@@ -84,10 +84,10 @@ vlc_module_begin ()
     set_subcategory( SUBCAT_VIDEO_VOUT )
     set_capability( "video output", 1 )
 
-    add_integer( "snapshot-width", 320, NULL, WIDTH_TEXT, WIDTH_LONGTEXT, false )
-    add_integer( "snapshot-height", 200, NULL, HEIGHT_TEXT, HEIGHT_LONGTEXT, false )
-    add_string( "snapshot-chroma", "RV32", NULL, CHROMA_TEXT, CHROMA_LONGTEXT, true )
-    add_integer( "snapshot-cache-size", 50, NULL, CACHE_TEXT, CACHE_LONGTEXT, true )
+    add_integer( "snapmod-width", 320, NULL, WIDTH_TEXT, WIDTH_LONGTEXT, false )
+    add_integer( "snapmod-height", 200, NULL, HEIGHT_TEXT, HEIGHT_LONGTEXT, false )
+    add_string( "snapmod-chroma", "RV32", NULL, CHROMA_TEXT, CHROMA_LONGTEXT, true )
+    add_integer( "snapmod-cache-size", 50, NULL, CACHE_TEXT, CACHE_LONGTEXT, true )
 
     set_callbacks( Create, Destroy )
 vlc_module_end ()
@@ -128,11 +128,11 @@ static int Create( vlc_object_t *p_this )
     if( ! p_vout->p_sys )
         return VLC_ENOMEM;
 
-    var_Create( p_vout, "snapshot-width", VLC_VAR_INTEGER );
-    var_Create( p_vout, "snapshot-height", VLC_VAR_INTEGER );
-    var_Create( p_vout, "snapshot-datasize", VLC_VAR_INTEGER );
-    var_Create( p_vout, "snapshot-cache-size", VLC_VAR_INTEGER );
-    var_Create( p_vout, "snapshot-list-pointer", VLC_VAR_ADDRESS );
+    var_Create( p_vout, "snapmod-width", VLC_VAR_INTEGER );
+    var_Create( p_vout, "snapmod-height", VLC_VAR_INTEGER );
+    var_Create( p_vout, "snapmod-datasize", VLC_VAR_INTEGER );
+    var_Create( p_vout, "snapmod-cache-size", VLC_VAR_INTEGER );
+    var_Create( p_vout, "snapmod-list-pointer", VLC_VAR_ADDRESS );
 
     p_vout->pf_init = Init;
     p_vout->pf_end = End;
@@ -157,10 +157,10 @@ static int Init( vout_thread_t *p_vout )
     int i_height;
     int i_datasize;
 
-    i_width  = config_GetInt( p_vout, "snapshot-width" );
-    i_height = config_GetInt( p_vout, "snapshot-height" );
+    i_width  = config_GetInt( p_vout, "snapmod-width" );
+    i_height = config_GetInt( p_vout, "snapmod-height" );
 
-    psz_chroma = config_GetPsz( p_vout, "snapshot-chroma" );
+    psz_chroma = config_GetPsz( p_vout, "snapmod-chroma" );
     if( !psz_chroma )
     {
         msg_Err( p_vout, "Cannot find chroma information." );
@@ -172,7 +172,7 @@ static int Init( vout_thread_t *p_vout )
 
     if( !i_chroma )
     {
-        msg_Err( p_vout, "snapshot-chroma should be 4 characters long" );
+        msg_Err( p_vout, "snapmod-chroma should be 4 characters long" );
         return VLC_EGENERIC;
     }
 
@@ -256,11 +256,11 @@ static int Init( vout_thread_t *p_vout )
 
     p_vout->p_sys->i_datasize = i_datasize;
     p_vout->p_sys->i_index = 0;
-    p_vout->p_sys->i_size = config_GetInt( p_vout, "snapshot-cache-size" );
+    p_vout->p_sys->i_size = config_GetInt( p_vout, "snapmod-cache-size" );
 
     if( p_vout->p_sys->i_size < 2 )
     {
-        msg_Err( p_vout, "snapshot-cache-size must be at least 1." );
+        msg_Err( p_vout, "snapmod-cache-size must be at least 1." );
         return VLC_EGENERIC;
     }
 
@@ -291,17 +291,17 @@ static int Init( vout_thread_t *p_vout )
     }
 
     val.i_int = i_width;
-    var_Set( p_vout, "snapshot-width", val );
+    var_Set( p_vout, "snapmod-width", val );
     val.i_int = i_height;
-    var_Set( p_vout, "snapshot-height", val );
+    var_Set( p_vout, "snapmod-height", val );
     val.i_int = i_datasize;
-    var_Set( p_vout, "snapshot-datasize", val );
+    var_Set( p_vout, "snapmod-datasize", val );
 
     val.i_int = p_vout->p_sys->i_size;
-    var_Set( p_vout, "snapshot-cache-size", val );
+    var_Set( p_vout, "snapmod-cache-size", val );
 
     val.p_address = p_vout->p_sys->p_list;
-    var_Set( p_vout, "snapshot-list-pointer", val );
+    var_Set( p_vout, "snapmod-list-pointer", val );
 
     /* Get the p_input pointer (to access video times) */
     p_vout->p_sys->p_input = vlc_object_find( p_vout, VLC_OBJECT_INPUT,
@@ -310,9 +310,9 @@ static int Init( vout_thread_t *p_vout )
     if( !p_vout->p_sys->p_input )
         return VLC_ENOOBJ;
 
-    if( var_Create( p_vout->p_sys->p_input, "snapshot-id", VLC_VAR_INTEGER ) )
+    if( var_Create( p_vout->p_sys->p_input, "snapmod-id", VLC_VAR_INTEGER ) )
     {
-        msg_Err( p_vout, "Cannot create snapshot-id variable in p_input(%p).",
+        msg_Err( p_vout, "Cannot create snapmod-id variable in p_input(%p).",
                  p_vout->p_sys->p_input );
         return VLC_EGENERIC;
     }
@@ -320,9 +320,9 @@ static int Init( vout_thread_t *p_vout )
     /* Register the snapshot vout module at the input level */
     val.p_address = p_vout;
 
-    if( var_Set( p_vout->p_sys->p_input, "snapshot-id", val ) )
+    if( var_Set( p_vout->p_sys->p_input, "snapmod-id", val ) )
     {
-        msg_Err( p_vout, "Cannot register snapshot-id in p_input(%p).",
+        msg_Err( p_vout, "Cannot register snapmod-id in p_input(%p).",
                  p_vout->p_sys->p_input );
         return VLC_EGENERIC;
     }
@@ -348,12 +348,12 @@ static void Destroy( vlc_object_t *p_this )
     vout_thread_t *p_vout = ( vout_thread_t * )p_this;
     int i_index;
 
-    var_Destroy( p_vout->p_sys->p_input, "snapshot-id" );
+    var_Destroy( p_vout->p_sys->p_input, "snapmod-id" );
 
     vlc_object_release( p_vout->p_sys->p_input );
-    var_Destroy( p_this, "snapshot-width" );
-    var_Destroy( p_this, "snapshot-height" );
-    var_Destroy( p_this, "snapshot-datasize" );
+    var_Destroy( p_this, "snapmod-width" );
+    var_Destroy( p_this, "snapmod-height" );
+    var_Destroy( p_this, "snapmod-datasize" );
 
     for( i_index = 0 ; i_index < p_vout->p_sys->i_size ; i_index++ )
     {
-- 
1.5.6.5

